#!/bin/sh
export PATH='/usr/obj/ports/hs-haskell-src-1.0.1.6/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: haskell-src
version: 1.0.1.6
id: haskell-src-1.0.1.6-db68be88b75c366219d787fc49d1aaf9

license: BSD3
copyright:
maintainer: Conrad Parker <conrad@metadecks.org>
stability:
homepage:
package-url:
synopsis: Support for manipulating Haskell source code
description: The '\''haskell-src'\'' package provides support for manipulating Haskell
             source code. The package provides a lexer, parser and
             pretty-printer, and a definition of a Haskell abstract syntax tree
             (AST). Common uses of this package are to parse or generate Haskell
             98 code.
category: Language
author: Simon Marlow, Sven Panne and Noel Winstanley
pkgpath: lang/hs-haskell-src
exposed: True
exposed-modules: Language.Haskell.Lexer Language.Haskell.Parser
                 Language.Haskell.ParseMonad Language.Haskell.Pretty
                 Language.Haskell.Syntax Language.Haskell.ParseUtils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.6
library-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.6
hs-libraries: HShaskell-src-1.0.1.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: array-0.5.0.0-8a40db6fafcaa8a9af9e4724885ba0bf
         base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
         pretty-1.1.1.1-acc3b405212f217732bea6bb8ac62790
         syb-0.4.1-706569d1ed7128dddfccaca8a9ef927f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-haskell-src-1.0.1.6/html/haskell-src.haddock
haddock-html: /usr/local/share/doc/hs-haskell-src-1.0.1.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
